@@ -83,6 +83,16 @@ notification_plugin_menu_clear (GtkWidget *widget, gpointer user_data)
 
 
 
+static void
+notification_plugin_clear_log_dialog (void) {
+  GtkWidget *dialog;
+
+  dialog = xfce_notify_clear_log_dialog ();
+  gtk_dialog_run (GTK_DIALOG (dialog));
+  gtk_widget_destroy (dialog);
+}
+
+
 void
 notification_plugin_menu_populate (NotificationPlugin *notification_plugin)
 {
@@ -146,6 +156,7 @@ notification_plugin_menu_populate (NotificationPlugin *notification_plugin)
     int log_length;
     int log_display_limit;
     int numberof_groups;
+    int numberof_notifications_shown = 0;
     gboolean log_only_today;
 
     groups = g_key_file_get_groups (notify_log, &num_groups);
@@ -171,7 +182,7 @@ notification_plugin_menu_populate (NotificationPlugin *notification_plugin)
     /* Notifications are only shown until LOG_DISPLAY_LIMIT is hit */
     for (i = numberof_groups; i > log_length; i--) {
       GtkWidget *grid;
-      GtkWidget *summary, *body, *app_icon, *expire_timeout;
+      GtkWidget *summary, *body, *app_icon;
       const gchar *group = groups[i];
       const char *format = "<b>\%s</b>";
       const char *tooltip_format = "<b>\%s</b> - \%s\n\%s";
@@ -184,9 +195,14 @@ notification_plugin_menu_populate (NotificationPlugin *notification_plugin)
       GDateTime *log_timestamp;
 
       /* optionally only show notifications from today */
-      if (log_only_today == TRUE)
-        if (g_ascii_strncasecmp (timestamp, group, 10) != 0)
+      if (log_only_today == TRUE) {
+        if (g_ascii_strncasecmp (timestamp, group, 10) != 0) {
+          no_notifications = TRUE;
           continue;
+        }
+        else
+          numberof_notifications_shown++;
+      }
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       mi = gtk_image_menu_item_new ();
 G_GNUC_END_IGNORE_DEPRECATIONS
@@ -213,9 +229,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
       tmp = g_key_file_get_string (notify_log, group, "body", NULL);
       body = gtk_label_new (NULL);
-      if (pango_parse_markup (tmp, -1, 0, NULL, NULL, NULL, NULL)) {
-        gtk_label_set_markup (GTK_LABEL (body), tmp);
-      } else {
+      gtk_label_set_markup (GTK_LABEL (body), tmp);
+      if (g_strcmp0 (gtk_label_get_text(GTK_LABEL (body)), "") == 0) {
         gchar *tmp1;
 
         tmp1 = g_markup_escape_text (tmp, -1);
@@ -246,10 +261,6 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 G_GNUC_END_IGNORE_DEPRECATIONS
       gtk_image_set_pixel_size (GTK_IMAGE (app_icon), log_icon_size);
 
-      tmp = g_key_file_get_string (notify_log, group, "expire-timeout", NULL);
-      expire_timeout = gtk_label_new (tmp);
-      g_free (tmp);
-
       grid = gtk_grid_new ();
       gtk_grid_set_column_spacing (GTK_GRID (grid), 6);
 
@@ -283,6 +294,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
     }
     g_strfreev (groups);
     g_key_file_free (notify_log);
+    if (numberof_notifications_shown > 0)
+      no_notifications = FALSE;
   }
   /* Show a placeholder label when there are no notifications */
   if (!notify_log ||
@@ -316,7 +329,7 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 G_GNUC_END_IGNORE_DEPRECATIONS
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
   gtk_widget_show (mi);
-  g_signal_connect (mi, "activate", G_CALLBACK (xfce_notify_log_clear),
+  g_signal_connect (mi, "activate", G_CALLBACK (notification_plugin_clear_log_dialog),
                     NULL);
 
   mi = gtk_menu_item_new_with_mnemonic (_("_Notification settings…"));
