@@ -290,7 +290,6 @@ xfce4_notifyd_mute_application (GtkListBox *known_applications_listbox,
     GtkWidget *mute_switch;
     gboolean muted;
     GPtrArray *muted_applications;
-    GPtrArray *new_array;
     GValue *val;
     guint i;
     const gchar *application_name;
@@ -569,7 +568,6 @@ xfce4_notifyd_log_populate (NotificationLogWidgets *log_widgets)
             GtkWidget *summary, *body, *app_icon, *expire_timeout;
             const gchar *group = groups[i];
             const char *format = "<b>\%s</b>";
-            const char *tooltip_format = "<b>\%s</b> - \%s\n\%s";
             const char *tooltip_format_simple = "<b>\%s</b> - \%s";
             char *markup;
             gchar *app_name;
@@ -610,9 +608,8 @@ xfce4_notifyd_log_populate (NotificationLogWidgets *log_widgets)
             g_free (markup);
             tmp = g_key_file_get_string (notify_log, group, "body", NULL);
             body = gtk_label_new (NULL);
-            if (pango_parse_markup (tmp, -1, 0, NULL, NULL, NULL, NULL)) {
-                gtk_label_set_markup (GTK_LABEL (body), tmp);
-            } else {
+            gtk_label_set_markup (GTK_LABEL (body), tmp);
+            if (g_strcmp0 (gtk_label_get_text (GTK_LABEL (body)), "") == 0) {
                 gchar *tmp1;
 
                 tmp1 = g_markup_escape_text (tmp, -1);
@@ -710,11 +707,14 @@ xfce4_notifyd_log_refresh (GtkButton *button, gpointer user_data) {
 static void xfce_notify_log_clear_button_clicked (GtkButton *button, gpointer user_data) {
     GtkWidget *log_listbox = ((NotificationLogWidgets *) user_data)->log_listbox;
     GtkCallback func = listbox_remove_all;
+    GtkWidget *dialog;
 
-    /* Clear the log file and empty the listbox widget */
-    gtk_container_foreach (GTK_CONTAINER (log_listbox), func, log_listbox);
-    xfce_notify_log_clear ();
-    xfce4_notifyd_log_populate (user_data);
+    dialog = xfce_notify_clear_log_dialog ();
+    gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+    /* Clear the listbox widget too in case the log is cleared */
+    if (result == GTK_RESPONSE_OK)
+        gtk_container_foreach (GTK_CONTAINER (log_listbox), func, log_listbox);
+    gtk_widget_destroy (dialog);
 }
 
 static void xfce4_notifyd_show_help(GtkButton *button,
@@ -784,7 +784,6 @@ xfce4_notifyd_config_setup_dialog(GtkBuilder *builder)
     GtkAdjustment *adj;
     GError *error = NULL;
     gchar *current_theme;
-    GKeyFile *notification_log;
     NotificationLogWidgets log_widgets;
     NotificationSlideoutWidgets slideout_widgets;
 
