@@ -25,6 +25,8 @@
 #include <string.h>
 #endif
 
+#include <glib/gstdio.h>
+
 #include <gtk/gtk.h>
 
 #include <xfconf/xfconf.h>
@@ -41,6 +43,7 @@ main(int argc,
     GError *error = NULL;
 
     xfconf_init(NULL);
+ 	
     gtk_init(&argc, &argv);
 
     xfce_textdomain(GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
@@ -58,10 +61,10 @@ main(int argc,
     xndaemon = xfce_notify_daemon_new_unique(&error);
     if(!xndaemon) {
         xfce_message_dialog(NULL, _("Xfce Notify Daemon"),
-                            GTK_STOCK_DIALOG_ERROR,
+                            "dialog-error",
                             _("Unable to start notification daemon"),
                             error->message,
-                            GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
+                            "application-exit", GTK_RESPONSE_ACCEPT,
                             NULL);
         g_error_free(error);
         return 1;
