@@ -1,7 +1,5 @@
 #include "xfce-notify-marshal.h"
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,7 +47,6 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* VOID:UINT,UINT (./xfce4-notifyd/xfce-notify-marshal.list:1) */
 void
 xfce_notify_marshal_VOID__UINT_UINT (GClosure     *closure,
@@ -59,13 +56,13 @@ xfce_notify_marshal_VOID__UINT_UINT (GClosure     *closure,
                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
-                                                guint        arg_1,
-                                                guint        arg_2,
-                                                gpointer     data2);
-  GMarshalFunc_VOID__UINT_UINT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer data1,
+                                                guint arg1,
+                                                guint arg2,
+                                                gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -96,13 +93,13 @@ xfce_notify_marshal_VOID__UINT_STRING (GClosure     *closure,
                                        gpointer      invocation_hint G_GNUC_UNUSED,
                                        gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_STRING) (gpointer     data1,
-                                                  guint        arg_1,
-                                                  gpointer     arg_2,
-                                                  gpointer     data2);
-  GMarshalFunc_VOID__UINT_STRING callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__UINT_STRING) (gpointer data1,
+                                                  guint arg1,
+                                                  gpointer arg2,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_STRING callback;
 
   g_return_if_fail (n_param_values == 3);
 
